@@ -1,21 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2008 Alexander Dymo <adymo@kdevelop.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008 Alexander Dymo <adymo@kdevelop.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #include "kshortcutschemeshelper_p.h"
 
 #include <QAction>
@@ -49,15 +38,16 @@ bool KShortcutSchemesHelper::saveShortcutScheme(const QList<KActionCollection *>
     // Maybe we need a checkbox for this? Or an env var for contributors to set, rather? End users don't care.
     const bool saveToApplicationFile = false;
 
-    QMap<QString, KActionCollection *> collectionsByClientName;
-    foreach (KActionCollection *coll, collections) {
+    QMultiMap<QString, KActionCollection *> collectionsByClientName;
+    for (KActionCollection *coll : collections) {
         const KXMLGUIClient *client = coll->parentGUIClient();
         if (client) {
             const QString key = saveToApplicationFile ? QCoreApplication::applicationName() : client->componentName();
-            collectionsByClientName.insertMulti(key, coll);
+            collectionsByClientName.insert(key, coll);
         }
     }
-    foreach (const QString &componentName, collectionsByClientName.uniqueKeys()) {
+    const auto componentNames = collectionsByClientName.uniqueKeys();
+    for (const QString &componentName : componentNames) {
 
         qCDebug(DEBUG_KXMLGUI) << "Considering component" << componentName;
         QDomDocument doc;
@@ -68,10 +58,12 @@ bool KShortcutSchemesHelper::saveShortcutScheme(const QList<KActionCollection *>
         QDomElement elem = doc.createElement(QStringLiteral("ActionProperties"));
         docElem.appendChild(elem);
 
-        foreach (KActionCollection *collection, collectionsByClientName.values(componentName)) {
+        const auto componentCollections = collectionsByClientName.values(componentName);
+        for (KActionCollection *collection : componentCollections) {
             qCDebug(DEBUG_KXMLGUI) << "Saving shortcut scheme for action collection with" << collection->actions().count() << "actions";
 
-            foreach (QAction *action, collection->actions()) {
+            const auto collectionActions = collection->actions();
+            for (QAction *action : collectionActions) {
                 if (!action) {
                     continue;
                 }
